export CLOUDSDK_ROOT_DIR=/opt/google-cloud-cli
export GOOGLE_CLOUD_SDK_HOME=$CLOUDSDK_ROOT_DIR
export CLOUDSDK_PYTHON=/usr/bin/python3
export CLOUDSDK_GSUTIL_PYTHON=/usr/bin/python3
export CLOUDSDK_BQ_PYTHON=/usr/bin/python3
#export CLOUDSDK_ENCODING
#export CLOUDSDK_PYTHON_ARGS
#export CLOUDSDK_PYTHON_SITEPACKAGES
